@@ -8,7 +8,7 @@ use Carp;
 use vars qw( $SOCKET_CLASS @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS $VERSION $SOCKS_ERROR $SOCKS5_RESOLVE $SOCKS4_RESOLVE $SOCKS_DEBUG %CODES );
 require Exporter;
 
-$VERSION = '0.66';
+$VERSION = '0.67';
 
 use constant {
 	SOCKS_WANT_READ  => 20,
@@ -16,7 +16,7 @@ use constant {
 	ESOCKSPROTO      => exists &Errno::EPROTO ? &Errno::EPROTO : 7000,
 };
 
-@ISA = ('Exporter');
+@ISA = ('Exporter', $SOCKET_CLASS||'');
 
 tie $SOCKET_CLASS, 'IO::Socket::Socks::SocketClassVar', $SOCKET_CLASS;
 unless ($SOCKET_CLASS) {
